     
def word_count(word_list):
    wordCount = {}
    for word in word_list:
        wordCount[word] = wordCount.get(word, 0) + 1
        sorted_dict = sorted(wordCount.items(), key=lambda x: x[1], reverse=True)
    return sorted_dict

def co_occurence_count(word_lst):
    co_dic = {}
    for i,a in enumerate(word_lst):
        #for b in word_lst[i+1:i+11]:
        for b in word_lst[i+1:]:
            if a == b: continue
            #print(i,a,b)
            if a > b: c, d = b, a
            else: c, d = a, b
            co_dic[c, d] = co_dic.get((c, d), 0) + 1
    return co_dic



# -*- coding: utf-8 -*-
import moko.noun_chunker as noun_chunker

def moko_demo():
    text = "論說\n⊙粤自循蜚、結繩遂寢、書契旣興以來、人生學業聞見之弘博必由載籍、以資考據、溫故而知新、明軆而達用、爲一世之木鐸、觀風問俗、軒猶猶能採訪、巴俚夏諺學士、不忘傳說、夫誰曰菊蕘之莫獻乎、在昔唐虞、有誹謗之木、矇瞍之箴皆、所以通達民隱、宣導政事、以佐一代太平之治、新聞之紙其倣諸斯乎、新聞紙者、掇滄海之遺珠、拾玄圃之積王、卽街談巷語、皆足以明習俗之純駁、上自國家之事務、以及金銀之漲落、與夫時勢之得失、無不洞悉、所謂不出戶庭、而週知天下之事者、豈外是哉、有此新聞紙之設、則下情、得以上達、而不至疾苦有所難宣。不亦快哉。蓋新聞紙之記者。無位無權然、盱衡世事、目格時艱、其立論公、其議事、當、不避權勢、不畏奸豪、遇有悖理肯棨之處、皆得從蓉論議、寓規諫之意、陳事勢之機、叙事則質而不俚、曲而善達、隱寓予奪之旨、儼操筆削之權、公是公菲、有勸懲之意、何毀何譽、持月朝之評、乃至天文、地理、宗敎、文學、農工、商賈、格致、算術、醫藥礦產、化學、重學、光學、以及乎稗官、野乘、謳歌、謠諑、靡不包羅、皆足以長人善德、增人才智者也、奸回、邪僻淫汚、荒誔、陰怪、不經之說、森露情形、俾皆知所以戒懼者也、其於世道風化、集思廣益、爲何如哉、周語、曰防民之口、甚於防川、川壅而决、傷人必多、民亦如之、是故爲川者、决之使導、爲民者、宣之使言、古有是哉、新聞紙之始自西歐、迄今垂五百載、各國、無不有之、多者、以千數、以國之有新聞紙、爲暗室燈人之閱新聞紙爲淸夜鐘、以新聞之盛衰、占國運之隆替、無他故也、國之有新聞、譬猶人身之有皿管、遡丹田、經歷六腑、上而返乎神經糸、周遭乎四肢百軆、日復如是然後、其血、不腐、其氣、不餒吾、故曰新聞紙之目的、以溫故而知新、明軆達用、爲一世之木鐸、無不可也、至於記者之掩阿回護、指鹿爲馬、誣罔虛誕者、社會之所不認者、而國法、乃裁制之耳"

    noun_list = noun_chunker.noun_chunk_dict(text)
    print("=== noun list with a dictionary ===")
    print(noun_list)

    noun_list = noun_chunker.noun_chunk_model(text)
    print("=== noun list with a model ===")
    print(noun_list)

moko_demo()


import hanja

def stopword_remove(word_lst, stopword_lst):
    lst = []
    for w in word_lst:
        if w in stopword_lst: continue
        else: lst.append(w)
    return lst

def adverb_remove(word_lst, adverb_lst):
    lst = []
    for w in word_lst:
        translated = hanja.translate(w,'substitution')
        if translated in adverb_lst: continue
        else: lst.append(w)
    return lst
